@@ -1,11 +1,12 @@
 #' @title Read  marker data.
 #' 
 #' @description
-#' A function for reading in marker data. Two types of data can be read. 
+#' A function for reading in different types of snp marker data. 
 #' @param filename contains the name of the marker  file. The file name needs to be in quotes. If the file is not in the working directory, then the full path 
 #' to the file is required.
-#' @param type  specify the type of file. Choices are 'text' (the default) and PLINK.
-#' @param missing the number or character for a missing genotype in the text file. There is no need to specify this for a PLINK ped file. Missing 
+#' @param type  specify the type of file. Choices are 'text' (the default) , PLINK, and vcf.
+#' @param missing the number or character for a missing genotype in the text file. There is no need to specify this for a vcf or PLINK ped file. Missing 
+#' allele values in a vcf file are coded as "." and missing 
 #' allele values in a PLINK file must be coded as '0' or '-'.  
 #' @param AA     the character or number corresponding to the 'AA' snp genotype in the marker genotype file. 
 #' This need only be specified if the file type is 'text'.  If a character then it must be in quotes.
@@ -22,8 +23,8 @@
 #' @param  quiet      a logical value. If set to \code{TRUE}, additional runtime output is printed. 
 #' @details
 #' 
-#' \code{ReadMarker} can handle two different types of marker data; namely,
-#' genotype data in a plain text file, and PLINK ped files. 
+#' \code{ReadMarker} can handle three different types of marker data; namely,
+#' genotype data in a plain text file, PLINK ped files, and vcf files.  
 #'  
 #' \subsection{\strong{Reading in a plain text file containing the marker genotypes}}{
 #' To load a text file that contains snp genotypes, run \code{ReadMarker} with \code{filename} set to the name of the file, 
@@ -86,6 +87,7 @@
 #' Full details of PLINK ped files can be found \url{https://www.cog-genomics.org/plink/1.9/formats#ped}. Briefly, 
 #' the PED file is a space delimited file (tabs are not allowed): the first six columns are mandatory:
 #'
+#'
 #' \tabular{l}{
 #'     Family ID  \cr
 #'     Individual ID \cr
@@ -118,28 +120,31 @@
 #' is being run). 
 #'}
 #'
+#' \subsection{\strong{Reading in a vcf file}}{
+#'  VCF is a tab separated text file containing  meta-information lines, a header line, and data 
+#' lines. The data lines  contain information about a position in the genome.
 #'
-#' \subsection{Reading in other formats}{
-#' Having first installed the stand-alone PLINK software, it is possible to convert other file formats into PLINK ped files. See \url{https://www.cog-genomics.org/plink/1.9/formats} for details. 
+#' It is assumed that genotype information has been recorded on samples for each position. 
 #'
-#' For example, to convert  vcf file into a PLINK ped file, at the unix prompt, use the PLINK command
+#' Loci with more than two alleles will be removed automatically. 
 #' 
-#' \preformatted{PLINK --vcf filename.vcf --recode --out newfilename}
-#'
-#' and to convert a binary ped file (bed) into a ped file, use the PLINK command
-#'
-#' \preformatted{PLINK --bfile filename --recode --tab --out newfilename}
-#'  
+#' Eagle will only accept a single (uncompressed) vcf file. If chromosomal information has been recorded in separate 
+#' vcf files, these files need to be merged into a single vcf file.  This can be done by using the 
+#'  BCFtools utility set with command line "bcftools concat".
 #'}
 #'
 #'
-#'
-#' @return  To allow \code{\link{AM}} to handle data larger than the memory capacity of a machine, \code{ReadMarker} doesn't load 
-#' the marker data into memory. Instead, it creates a reformatted file of the marker data and its transpose. The object returned by
-#' \code{ReadMarker} is a list object with the elements \code{asciifileM} , \code{asciifileMt}, and \code{dim_of_ascii_M}  
+#' @return  
+#' To allow Eagle to handle data larger than the memory capacity of a machine, \code{ReadMarker} doesn't load 
+#' the marker data into memory. Instead, it 
+#' writes a reformatted version of the marker data, and its transpose, to the harddrive. These two files
+#' are only temporary, being removed at the end of the R session. 
+#' The object returned by
+#' \code{ReadMarker} is a list object with the elements \code{tmpM} , \code{tmpMt}, and \code{dim_of_M}  
 #' which is the full file name (name and path)  of the reformatted file for the marker  data,  the full file name of the reformatted file 
 #' for the transpose of the marker  data,  and a 2 element vector with the first element the number of individuals and the second 
 #' element the number of marker loci. 
+#'
 #' 
 #'
 #' @examples
@@ -190,6 +195,28 @@
 #'   print(geno_obj)
 #'
 #'
+#'
+#'   #--------------------------------
+#'   #  Example 3
+#'   #-------------------------------
+#'   #
+#'   #
+#'   # Read in the genotype data contained in the vcf file geno.vcf
+#'   #
+#'   # The function system.file() gives the full file name (name + full path).
+#'   complete.name <- system.file('extdata', 'geno.vcf', package='Eagle')
+#'   # 
+#'   # The full path and name of the file is
+#'   print(complete.name)
+#'   
+#'   # The file contains 5 marker loci recorded on 3 individuals
+#'   # Two of the loci contain multiple alleles and are removed. 
+#'   # A summary of the file is printed once the file has been read.
+#'   geno_obj <- ReadMarker(filename=complete.name, type="vcf", availmemGb=4) 
+#'    
+#'   # view list contents of geno_obj
+#'   print(geno_obj)
+#'
 ReadMarker <- function( filename=NULL, type='text', missing=NULL,
                            AA=NULL, AB=NULL, BB=NULL, 
                            availmemGb=16, 
@@ -203,12 +230,12 @@ ReadMarker <- function( filename=NULL, type='text', missing=NULL,
  }  else {
       ## read in either a text file or a PLINK file. The parameter type must be specified. Default it text file. 
    if(is.null(type)){
-      message(" type must be set to \"text\" or \"PLINK\". \n")
+      message(" type must be set to \"text\" ,\"PLINK\", or \"vcf\". \n")
       message(" ReadMarker has terminated with errors.")
       return(FALSE)
    }
-   if(!(type=="text" || type=="PLINK") ){
-      message(" type must be set to \"text\" or \"PLINK\". \n")
+   if(!(type=="text" || type=="PLINK" || type=="vcf") ){
+       message(" type must be set to \"text\" ,\"PLINK\", or \"vcf\". \n")
       message(" ReadMarker has terminated with errors")
       return(FALSE)
    }
@@ -230,25 +257,27 @@ ReadMarker <- function( filename=NULL, type='text', missing=NULL,
        }
 
        ## Rcpp function to get dimensions of PLINK ped  file
-       dim_of_ascii_M <- getRowColumn(fname=fullpath(filename))
-       dim_of_ascii_M[2] <- (dim_of_ascii_M[2] - 6)/2  ## adjusting for PLINK structure
+       dim_of_M <- getRowColumn(fname=fullpath(filename))
+       dim_of_M[2] <- (dim_of_M[2] - 6)/2  ## adjusting for PLINK structure
        ## Rcpp function to create binary packed Mt and M file (if needed)
-       it_worked <- create.bin(file_genotype=fullpath(filename), type=type, availmemGb=availmemGb, dim_of_ascii_M=dim_of_ascii_M,  quiet=quiet  )
+       it_worked <- create.bin(file_genotype=fullpath(filename), type=type, availmemGb=availmemGb, dim_of_M=dim_of_M,  quiet=quiet  )
        if(!it_worked)
            return(FALSE) 
 
     if(.Platform$OS.type == "unix") {
-       asciifileM <- paste(tempdir(), "/", "M.bin", sep="")
-       asciifileMt <- paste(tempdir(), "/", "Mt.bin", sep="")
+       tmpM <- paste(tempdir(), "/", "M.bin", sep="")
+       tmpMt <- paste(tempdir(), "/", "Mt.bin", sep="")
      } else {
-       asciifileM <- paste(tempdir()  , "\\", "M.bin", sep="")
-       asciifileMt <- paste(tempdir() , "\\", "Mt.bin", sep="")
+       tmpM <- paste(tempdir()  , "\\", "M.bin", sep="")
+       tmpMt <- paste(tempdir() , "\\", "Mt.bin", sep="")
      }
 
 
 
 
-   }  else {
+   }  
+   if (type == "text"){
+
       ## ------------  text file -----------------------
       ## Assuming a text file that may be comma separated with numeric genotypes that need to be mapped onto AA, AB, and BB. 
       ## check of parameters
@@ -279,13 +308,13 @@ ReadMarker <- function( filename=NULL, type='text', missing=NULL,
 
   ## Rcpp function to get dimensions of ASCII genotype file
   message(" Getting number of individuals and snp from file ... ")
-  dim_of_ascii_M <- getRowColumn(fname=genofile)
+  dim_of_M <- getRowColumn(fname=genofile)
 
   ## Rcpp function to create ascii  M and Mt file from 
   message(" Beginning creation of reformatted file ... ")
   message(" Reading marker data ... \n")
   it_worked <- create.bin(file_genotype=genofile, type=type, AA=as.character(AA), AB=as.character(AB), BB=as.character(BB), 
-              availmemGb=availmemGb, dim_of_ascii_M=dim_of_ascii_M, quiet=quiet, missing=missing  )
+              availmemGb=availmemGb, dim_of_M=dim_of_M, quiet=quiet, missing=missing  )
 
     if(!it_worked)   ## error has occurred. 
        return(FALSE)
@@ -293,20 +322,30 @@ ReadMarker <- function( filename=NULL, type='text', missing=NULL,
 
 
      if(.Platform$OS.type == "unix") {
-       asciifileM <- paste(tempdir() , "/", "M.bin", sep="")
-       asciifileMt <- paste(tempdir() , "/", "Mt.bin", sep="")
+       tmpM <- paste(tempdir() , "/", "M.bin", sep="")
+       tmpMt <- paste(tempdir() , "/", "Mt.bin", sep="")
      } else {
-       asciifileM <- paste(tempdir() , "\\", "M.bin", sep="")
-       asciifileMt <- paste(tempdir() , "\\", "Mt.bin", sep="")
+       tmpM <- paste(tempdir() , "\\", "M.bin", sep="")
+       tmpMt <- paste(tempdir() , "\\", "Mt.bin", sep="")
      }
 
 
  
   }  ## end if else nargs()==1  (PLINK case)
 
-  geno <- list("asciifileM"=asciifileM, "asciifileMt"=asciifileMt,
-               "dim_of_ascii_M" = dim_of_ascii_M,       
-               "dim_of_ascii_Mt" = c(dim_of_ascii_M[2], dim_of_ascii_M[1]),
+
+  if (type == "vcf"){
+     geno <- ReadVCF( filename=filename, availmemGb=availmemGb, quiet=TRUE )
+
+  }
+
+
+
+
+  if(type != "vcf"){
+  geno <- list("tmpM"=tmpM, "tmpMt"=tmpMt,
+               "dim_of_M" = dim_of_M,       
+               "dim_of_Mt" = c(dim_of_M[2], dim_of_M[1]),
                "availmemGb" = availmemGb )
 
   if(.Platform$OS.type == "unix") {
@@ -319,6 +358,9 @@ ReadMarker <- function( filename=NULL, type='text', missing=NULL,
 
 
   save(geno, file=RDatafile)
+
+}
+
   ## create M.Rdata file in current directory
   return(geno)
 
