@@ -89,13 +89,13 @@ row4Anal <- function()
 {
 page =  fluidRow( column(12, 
          wellPanel(
-          radioButtons(inputId="analyse_gamma", label=h4("Step 4: Specify gamma value (controls the false positive rate)"), 
+          radioButtons(inputId="analyse_lambda", label=h4("Step 4: Specify lambda value (controls the false positive rate)"), 
         choiceNames = list(
         tags$span(style = "font-size:18px", "Set manually"),
         tags$span(style = "font-size:18px", "Set automatically (via permutation)")),
                                                     choiceValues=c("manual","auto")),
                         style="padding: 1px",
- shinyBS::bsTooltip("analyse_gamma", title='<font size="3" > Select the manual option if you want a quick analysis. If you leave the gamma value at 1, its default value, this will be a conservative analysis. Select auto if you want to perform an analysis with a specified false positive rate. This analysis will take about 5 times as long as a permutation step is performed to fine-tune the gamma value for the desired false positive rate.  </font>',
+ shinyBS::bsTooltip("analyse_lambda", title='<font size="3" > Select the manual option if you want a quick analysis. If you leave the lambda value at 1, its default value, this will be a conservative analysis. Select auto if you want to perform an analysis with a specified false positive rate. This analysis will take about 5 times as long as a permutation step is performed to fine-tune the lambda value for the desired false positive rate.  </font>',
                                placement="right", trigger="hover", options=list(container="body"))
 
                      )  ## column 12
@@ -103,13 +103,13 @@ page =  fluidRow( column(12,
                                           
 
                 conditionalPanel(
-                   condition = "input.analyse_gamma == 'manual'",
+                   condition = "input.analyse_lambda == 'manual'",
                         wellPanel(
                         fluidRow(column(12,
-                           sliderInput(inputId="analyse_setgamma", label=h4("Specify gamma value. "),
+                           sliderInput(inputId="analyse_setlambda", label=h4("Specify lambda value. "),
                                value=1, min = 0, max = 1, step = 0.01),
                            style="padding: 1px",
-                           shinyBS::bsTooltip("analyse_setgamma", title='<font size="3" >The gamma parameter controls the conservativeness of the model building process. Values closer to 1 (0) decrease (increase) the false positive rate. The default value is 1 - its most conservative setting. </font>',
+                           shinyBS::bsTooltip("analyse_setlambda", title='<font size="3" >The lambda parameter controls the conservativeness of the model building process. Values closer to 1 (0) decrease (increase) the false positive rate. The default value is 1 - its most conservative setting. </font>',
                                placement="right", trigger="hover", options=list(container="body"))
                                ) ## colunn12,
                            ) ## fluidRow
@@ -117,7 +117,7 @@ page =  fluidRow( column(12,
                 ), ## conditionalPanel
 
                 conditionalPanel(
-                   condition = "input.analyse_gamma == 'auto'",
+                   condition = "input.analyse_lambda == 'auto'",
                         wellPanel(
                        fluidRow(column(12, 
                            sliderInput(inputId="analyse_fpr", label=h4("Specify desired false positive rate."),
@@ -135,7 +135,7 @@ page =  fluidRow( column(12,
                    sliderInput(inputId="analyse_numreps", label=h4(" Specify number of replicates."),
                                        value=200, min = 30, max = 1000, step = 5),
                                         style="padding: 1px",
-                   shinyBS::bsTooltip("analyse_numreps", title='<font size="3" > To set the number of replicates, start with 200 replicates and increase in 50 replicate increments. Stop when the gamma value stabilizes.  </font>',
+                   shinyBS::bsTooltip("analyse_numreps", title='<font size="3" > To set the number of replicates, start with 200 replicates and increase in 50 replicate increments. Stop when the lambda value stabilizes.  </font>',
                           placement="right", trigger="hover", options=list(container="body"))
 
 
@@ -170,7 +170,7 @@ row5Anal <- function()
                                          icon=icon("upload", lib="glyphicon")),
                                           style='padding: 1px',
                                         shinyBS::bsTooltip("analyse_go",
-                     title='<font size="3" >  Click here to find the set of snp in strongest association with the trait. Manually setting the gamma value is much faster than having the gamma value set automatically. However, automatically is the preferred option.  </font>',
+                     title='<font size="3" >  Click here to find the set of snp in strongest association with the trait. Manually setting the lambda value is much faster than having the lambda value set automatically. However, automatically is the preferred option.  </font>',
                           placement="right", trigger="hover",
                           options=list(container="body"))
              ) ## wellPanel
@@ -1567,7 +1567,11 @@ server <- function(input, output, session){
                  shinyjs::html("ReadMap", "")
          
                  if (file.exists(path_to_map_file) == TRUE) {
-                    map  <<- ReadMap(filename = path_to_map_file, csv=csv_flag, header= map_header_flag)
+                    if(csv_flag){
+                       map  <<- ReadMap(filename = path_to_map_file, sep="," , header= map_header_flag)            
+                    } else {
+                       map  <<- ReadMap(filename = path_to_map_file, header= map_header_flag)            
+                    }   ## ed if csv_flag 
                  }  else {
                     shinyjs::html(id = "ReadMap", html = paste0("ReadMap", "File does not exist:", path_to_map_file))
                  }
@@ -1633,15 +1637,16 @@ server <- function(input, output, session){
      })
 
 
-
-  sz <- 0
+sz <- 0
   output$analyse_names <- renderUI({
-   if (length(nms) < 5){
-       sz <- length(nms)
+   if (length(nms()) < 5){
+       sz <- length(nms())
    } else {
        sz <- 5
    }
 
+
+
   selectInput(inputId="nmst", label=h4("Step 1: Choose trait"), choices=nms(), size = sz   , selectize=FALSE )     
   })  ## end renderUI
 
@@ -1669,7 +1674,7 @@ server <- function(input, output, session){
 
  ##  AM analysis for calculation of FPR
 # res <- NULL
-setgamma <- 1
+setlambda <- 1
 
    #observeEvent((input$analyse_go & input$pheno_go & input$marker_go) , {
  observeEvent(input$marker_go, {
@@ -1678,14 +1683,14 @@ setgamma <- 1
    withProgress(message = 'Analysing data', value = 1, {
        fform <<- paste(input$nmsf, collapse="+")
 
-     if(input$analyse_gamma=="manual"){
+     if(input$analyse_lambda=="manual"){
 
         withCallingHandlers({
                   shinyjs::html("AM", "")
                   res <<- AM(trait=input$nmst , fformula=fform , 
-                             gamma=input$analyse_setgamma,
+                             lambda=input$analyse_setlambda,
                              ncpu = input$analyse_cpu,  pheno = pheno, geno=geno, map=map, Zmat=Zmat)
-                  setgamma <<- input$analyse_setgamma 
+                  setlambda <<- input$analyse_setlambda 
                },  ## end withCallingHandlers
                message = function(m) {
                   shinyjs::html(id = "AM", html = m$message, add = TRUE)
@@ -1696,7 +1701,7 @@ setgamma <- 1
      }
 
 
-     if(input$analyse_gamma=="auto"){
+     if(input$analyse_lambda=="auto"){
        
            withCallingHandlers({
                  shinyjs::html("AM", "")
@@ -1706,10 +1711,10 @@ setgamma <- 1
                             ncpu = input$analyse_cpu,  pheno = pheno, geno=geno, map=map, Zmat = Zmat) 
          
                   if(!is.null(res)){ 
-                    setgamma <<- res$setgamma
+                    setlambda <<- res$setlambda
                  
                     res <<- AM(trait=input$nmst , fformula=fform , 
-                             gamma=res$setgamma,
+                             lambda=res$setlambda,
                              ncpu = input$analyse_cpu,  pheno = pheno, geno=geno, map=map, Zmat=Zmat)
                   }
 
@@ -2034,10 +2039,10 @@ setgamma <- 1
  dfparams <- NULL
 
  if(!is.null(fform))
-    dfparams <- data.frame(Parameters=c("Trait", "Fixed effects", "Working memory", "Number CPU", "Gamma"), Settings=c(input$nmst, as.character(fform), input$memsize, input$analyse_cpu, round(setgamma,3)))
+    dfparams <- data.frame(Parameters=c("Trait", "Fixed effects", "Working memory", "Number CPU", "Gamma"), Settings=c(input$nmst, as.character(fform), input$memsize, input$analyse_cpu, round(setlambda,3)))
 
  if(is.null(fform))
-   dfparams <- data.frame(Parameters=c("Trait", "Fixed effects", "Working memory", "Number CPU", "Gamma"), Settings=c(input$nmst, "overall mean" , input$memsize, input$analyse_cpu, round(setgamma,3)))   
+   dfparams <- data.frame(Parameters=c("Trait", "Fixed effects", "Working memory", "Number CPU", "Gamma"), Settings=c(input$nmst, "overall mean" , input$memsize, input$analyse_cpu, round(setlambda,3)))   
 
  output$parameters <- renderTable(dfparams) 
 
@@ -2188,7 +2193,7 @@ This page goes through the steps that are needed to analyse the data.
 In the first step, the column in the phenotype file containing the trait data is specified. 
 In the second step, any fixed effects are specified. If no fixed effects are selected, the fixed effects part of the model only contains an overall mean. 
 In the thrid step, the number of available CPU is set. The default is 1 but if more are available, increasing this number will improve performance significantly. 
-The fourth step is to set the gamma parameter. The gamma parameter controls the conservativeness (or false positive rate) of the model building process. For a quick preliminary analysis of the 
+The fourth step is to set the lambda parameter. The lambda parameter controls the conservativeness (or false positive rate) of the model building process. For a quick preliminary analysis of the 
 data, choose the manual option and leave the parameter at its default setting. For a more detailed analysis of the data where the false positive rate is prespecified, 
 choose the auto option. 
 <br><br>
